scGPT
=================

.. include:: ./model_cards/scgpt.md
   :parser: myst_parser.sphinx_

.. currentmodule:: helical.models.scgpt.model
.. automodule:: helical.models.scgpt.model

.. autosummary::
   :toctree: _autosummary

   scGPT
   scGPTConfig
   scGPT.process_data
   scGPT.get_embeddings
   

